==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectInstance.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectinstance_h
#define objectinstance_h
#include <admsObject/admsH.h>
#include <admsObject/objectMath.h>
struct s_instance {
  t_math _math;
  p_module _instantiator;
  int _instantiator_isdefault : 1;
  p_module _module;
  int _module_isdefault : 1;
  char* _name;
  int _name_isdefault : 1;
  GSList* _terminal;
  int _terminal_isdefault : 1;
  GSList* _parameterset;
  int _parameterset_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectInstancenode.h>
#include <admsObject/objectInstanceparameter.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_instance_getuid (p_instance myinstance);
win32_interface gboolean adms_instance_cmp (p_instance myinstance,p_instance refinstance);
win32_interface p_instance adms_instance_new_1 (p_module myinstantiator,p_module mymodule,char* myname);
#define adms_instance_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_instance_free(item)\
{\
  free(item->_name);\
  free(item);\
}
win32_interface p_adms adms_instance_new_impl (p_adms arguments[]);
win32_interface p_instance adms_instance_impl (void* member);
#define adms_instance(member) ((p_instance) (member))
#define adms_instance_new adms_instance_new_1
#define adms_instance_isdefault_instantiator(instance) (adms_instance(instance)->_instantiator_isdefault)
#define adms_instance_valueof_instantiator(instance) (adms_instance(instance)->_instantiator)
#define adms_instance_isdefault_module(instance) (adms_instance(instance)->_module_isdefault)
#define adms_instance_valueof_module(instance) (adms_instance(instance)->_module)
#define adms_instance_isdefault_name(instance) (adms_instance(instance)->_name_isdefault)
#define adms_instance_valueof_name(instance) (adms_instance(instance)->_name)
#define adms_instance_isdefault_terminal(instance) (adms_instance(instance)->_terminal_isdefault)
#define adms_instance_valueof_terminal(instance) (adms_instance(instance)->_terminal)
#define adms_instance_isdefault_parameterset(instance) (adms_instance(instance)->_parameterset_isdefault)
#define adms_instance_valueof_parameterset(instance) (adms_instance(instance)->_parameterset)
#define adms_instance_valueof_math(instance) ((p_math)instance)
#define adms_instance_valueof_adms(instance) ((p_adms)instance)
#define adms_instance_valueto_instantiator(a,b) ((p_instance)a)->_instantiator=(b)
win32_interface void adms_instance_valueto_instantiator_impl (p_instance myinstance,p_module _instantiator);
#define adms_instance_valueto_module(a,b) ((p_instance)a)->_module=(b)
win32_interface void adms_instance_valueto_module_impl (p_instance myinstance,p_module _module);
#define adms_instance_valueto_name(a,b) ((p_instance)a)->_name=(b)
win32_interface void adms_instance_valueto_name_impl (p_instance myinstance,char* _name);
#define adms_instance_valueto_terminal(a,b) ((p_instance)a)->_terminal=(b)
win32_interface void adms_instance_valueto_terminal_impl (p_instance myinstance,GSList* _terminal);
win32_interface p_instancenode adms_instance_list_terminal_lookup_by_id (p_instance mymyinstance,p_node mynodefrominstantiator,p_node mynodefrommodule);
win32_interface p_instancenode adms_instance_list_terminal_prepend_by_id (p_instance mymyinstance,p_node mynodefrominstantiator,p_node mynodefrommodule);
win32_interface p_instancenode adms_instance_list_terminal_prepend_by_id_once_or_abort (p_instance mymyinstance,p_node mynodefrominstantiator,p_node mynodefrommodule);
win32_interface void adms_instance_list_terminal_prepend_once_or_abort (p_instance mymyinstance,p_instancenode myterminal);
#define adms_instance_valueto_parameterset(a,b) ((p_instance)a)->_parameterset=(b)
win32_interface void adms_instance_valueto_parameterset_impl (p_instance myinstance,GSList* _parameterset);
win32_interface p_instanceparameter adms_instance_list_parameterset_lookup_by_id (p_instance mymyinstance,p_variable myparameter);
win32_interface p_instanceparameter adms_instance_list_parameterset_prepend_by_id (p_instance mymyinstance,p_variable myparameter);
win32_interface p_instanceparameter adms_instance_list_parameterset_prepend_by_id_once_or_abort (p_instance mymyinstance,p_variable myparameter);
win32_interface void adms_instance_list_parameterset_prepend_once_or_abort (p_instance mymyinstance,p_instanceparameter myparameterset);
#endif /* objectinstance_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectInstance.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectinstance_h
#define objectinstance_h
#include <admsObject/admsH.h>
#include <admsObject/objectMath.h>
struct s_instance {
  t_math _math;
  p_module _instantiator;
  int _instantiator_isdefault : 1;
  p_module _module;
  int _module_isdefault : 1;
  p_quark _name;
  int _name_isdefault : 1;
  p_slist _terminal;
  int _terminal_isdefault : 1;
  p_slist _parameterset;
  int _parameterset_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectQuark.h>
#include <admsObject/objectInstancenode.h>
#include <admsObject/objectInstanceparameter.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_instance_uid (p_instance myinstance);
win32_interface int adms_instance_cmp (p_instance myinstance,p_instance refinstance);
win32_interface p_instance adms_instance_new(p_module myinstantiator,p_module mymodule,p_quark myname);
win32_interface p_adms adms_instance_new_impl (p_adms arguments[]);
#define adms_instance(member) ((p_instance) (member))
#define adms_instance_isdefault_instantiator(instance) (adms_instance(instance)->_instantiator_isdefault)
#define adms_instance_valueof_instantiator(instance) (adms_instance(instance)->_instantiator)
#define adms_instance_isdefault_module(instance) (adms_instance(instance)->_module_isdefault)
#define adms_instance_valueof_module(instance) (adms_instance(instance)->_module)
#define adms_instance_isdefault_name(instance) (adms_instance(instance)->_name_isdefault)
#define adms_instance_valueof_name(instance) (adms_instance(instance)->_name)
#define adms_instance_isdefault_terminal(instance) (adms_instance(instance)->_terminal_isdefault)
#define adms_instance_valueof_terminal(instance) (adms_instance(instance)->_terminal)
#define adms_instance_isdefault_parameterset(instance) (adms_instance(instance)->_parameterset_isdefault)
#define adms_instance_valueof_parameterset(instance) (adms_instance(instance)->_parameterset)
#define adms_instance_valueof_math(instance) ((p_math)instance)
#define adms_instance_valueof_adms(instance) ((p_adms)instance)
win32_interface inline void adms_instance_valueto_instantiator (p_instance myinstance,p_module _instantiator);
win32_interface inline void adms_instance_valueto_module (p_instance myinstance,p_module _module);
win32_interface inline void adms_instance_valueto_name (p_instance myinstance,p_quark _name);
win32_interface inline void adms_instance_valueto_terminal (p_instance myinstance,p_slist _terminal);
win32_interface p_instancenode adms_instance_list_terminal_lookup_by_id (p_instance mymyinstance,p_node mynodefrominstantiator,p_node mynodefrommodule);
win32_interface p_instancenode adms_instance_list_terminal_prepend_by_id (p_instance mymyinstance,p_node mynodefrominstantiator,p_node mynodefrommodule);
win32_interface p_instancenode adms_instance_list_terminal_prepend_by_id_once_or_abort (p_instance mymyinstance,p_node mynodefrominstantiator,p_node mynodefrommodule);
win32_interface void adms_instance_list_terminal_prepend_once_or_abort (p_instance mymyinstance,p_instancenode myterminal);
win32_interface inline void adms_instance_valueto_parameterset (p_instance myinstance,p_slist _parameterset);
win32_interface p_instanceparameter adms_instance_list_parameterset_lookup_by_id (p_instance mymyinstance,p_variable myparameter);
win32_interface p_instanceparameter adms_instance_list_parameterset_prepend_by_id (p_instance mymyinstance,p_variable myparameter);
win32_interface p_instanceparameter adms_instance_list_parameterset_prepend_by_id_once_or_abort (p_instance mymyinstance,p_variable myparameter);
win32_interface void adms_instance_list_parameterset_prepend_once_or_abort (p_instance mymyinstance,p_instanceparameter myparameterset);
win32_interface inline void adms_instance_free(p_instance myinstance);
#endif /* objectinstance_h */
